@@ -21,7 +21,7 @@ class MainCommand(Command):
                                 nextcloud_username=self.argument('username'),
                                 nextcloud_password=self.argument('password'),
                                 iface=self.argument('iface'),
-                                dns_api_key=self.argument('dns'))
+                                dns_api_key=self.argument('dns-key'))
 
         setup.configure(self.argument('service'))
 
